Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(153)

Unified Diff: android_webview/java/src/org/chromium/android_webview/AwContentsIoThreadClient.java

Issue 11419093: [Android WebView] Implement WebSettings.{get|set}CacheMode (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merged after the last changes Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: android_webview/java/src/org/chromium/android_webview/AwContentsIoThreadClient.java
diff --git a/android_webview/java/src/org/chromium/android_webview/AwContentsIoThreadClient.java b/android_webview/java/src/org/chromium/android_webview/AwContentsIoThreadClient.java
index b656a05acf0d18410ac462ad2fc8df2a3f0834fb..284f0fc8e26cc8228e368a381cfbb9e65ce40437 100644
--- a/android_webview/java/src/org/chromium/android_webview/AwContentsIoThreadClient.java
+++ b/android_webview/java/src/org/chromium/android_webview/AwContentsIoThreadClient.java
@@ -8,27 +8,25 @@ import org.chromium.base.CalledByNative;
import org.chromium.base.JNINamespace;
/**
* Delegate for handling callbacks from the IO thread on the IO thread.
*
- * The shouldInterceptRequest method will be called on the IO thread.
* You should create a separate instance for every WebContents that requires the
* provided functionality.
*/
@JNINamespace("android_webview")
public interface AwContentsIoThreadClient {
- // Called on the IO thread.
+ @CalledByNative
+ public int getCacheMode();
+
@CalledByNative
public InterceptedRequestData shouldInterceptRequest(String url);
- // Called on the IO thread.
@CalledByNative
public boolean shouldBlockContentUrls();
- // Called on the IO thread.
@CalledByNative
public boolean shouldBlockFileUrls();
- // Called on the IO thread.
@CalledByNative
public boolean shouldBlockNetworkLoads();
}
@@ -8,27 +8,25 @@ import org.chromium.base.CalledByNative;
import org.chromium.base.JNINamespace;
/**
- * Delegate for handling callbacks from the IO thread on the IO thread.
+ * Delegate for handling callbacks. All methods are called on the IO thread.
*

Powered by Google App Engine
This is Rietveld 408576698